Learn R Programming

hyfo (version 1.3.6)

collectData_txt_anarbe: collect data from different txt.

Description

collect data from different txt.

Usage

collectData_txt_anarbe(folderName, output = TRUE, rangeWord = c("Ene ", -1, "Total ", -6))

Arguments

folderName
A string showing the folder path.
output
A boolean showing whether the result is given.
rangeWord
A list containing the keyword and the shift. defaut is set to be used in spain gauging station.

Value

The collected data from different txt files.

http://www4.gipuzkoa.net/oohh/web/esp/02.asp

References

  • http://www4.gipuzkoa.net/oohh/web/esp/02.asp
  • R Core Team (2015). R: A language and environment for statistical computing. R Foundation for Statistical Computing, Vienna, Austria. URL http://www.R-project.org/.

Examples

Run this code
#use internal data as an example.

## Not run: 
# file <- system.file("extdata", "1999.csv", package = "hyfo")
# folder <- strsplit(file, '1999')[[1]][1]
# a <- collectData_txt_anarbe(folder)
# ## End(Not run)


# More examples can be found in the user manual on http://yuanchao-xu.github.io/hyfo/

Run the code above in your browser using DataLab