Rdocumentation
powered by
Learn R Programming
hyfo (version 1.3.4)
monthlyPreci: Get monthly rainfall
Description
Get monthly rainfall
Usage
monthlyPreci(TS, year, mon)
Arguments
TS
A rainfall time series.
year
A list showing the year index of the time series.
mon
A list showing the mon index of the time series.
Value
the monthly rainfall matrix of the rainfall time series.